const { performance } = require("perf_hooks");

const src = require("fs").readFileSync(__dirname + "/large.js", "utf-8");

const swc = require("./");
const { parse } = require("@babel/parser");
const generate = require("@babel/generator").default;

const TESTS = [
  ["swc", () => swc.printSync(swc.parseSync(src))],
  [
    "swc (srcmap)",
    () => swc.printSync(swc.parseSync(src), { sourceMaps: true })
  ],
  [
    "babel",
    () => {
      const ast = parse(src);
      return generate(
        ast,
        {
          sourceFileName: "input.js"
        },
        src
      );
    }
  ],
  [
    "babel (srcmap)",
    () => {
      const ast = parse(src);
      return generate(
        ast,
        {
          sourceMaps: true,
          sourceFileName: "input.js"
        },
        src
      );
    }
  ]
];

for (const [name, op] of TESTS) {
  console.info(`Testing: ${name}`);
  const start = performance.now();
  for (const i of [0, 1, 2, 3, 4]) {
    op();
  }
  const end = performance.now();

  console.info(`Time: ${end - start}`);
}
